==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V2beta2MetricValueStatusFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.Integer;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V2beta2MetricValueStatusFluentImpl<A extends V2beta2MetricValueStatusFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V2beta2MetricValueStatusFluent<A>{

    private Integer averageUtilization;
    private String averageValue;
    private String value;

    public V2beta2MetricValueStatusFluentImpl(){
    }
    public V2beta2MetricValueStatusFluentImpl(V2beta2MetricValueStatus instance){
            this.withAverageUtilization(instance.getAverageUtilization());

            this.withAverageValue(instance.getAverageValue());

            this.withValue(instance.getValue());

    }

    public Integer getAverageUtilization(){
            return this.averageUtilization;
    }

    public A withAverageUtilization(Integer averageUtilization){
            this.averageUtilization=averageUtilization; return (A) this;
    }

    public Boolean hasAverageUtilization(){
            return this.averageUtilization != null;
    }

    public A withNewAverageUtilization(int arg1){
            return (A)withAverageUtilization(new Integer(arg1));
    }

    public A withNewAverageUtilization(String arg1){
            return (A)withAverageUtilization(new Integer(arg1));
    }

    public String getAverageValue(){
            return this.averageValue;
    }

    public A withAverageValue(String averageValue){
            this.averageValue=averageValue; return (A) this;
    }

    public Boolean hasAverageValue(){
            return this.averageValue != null;
    }

    public String getValue(){
            return this.value;
    }

    public A withValue(String value){
            this.value=value; return (A) this;
    }

    public Boolean hasValue(){
            return this.value != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V2beta2MetricValueStatusFluentImpl that = (V2beta2MetricValueStatusFluentImpl) o;
            if (averageUtilization != null ? !averageUtilization.equals(that.averageUtilization) :that.averageUtilization != null) return false;
            if (averageValue != null ? !averageValue.equals(that.averageValue) :that.averageValue != null) return false;
            if (value != null ? !value.equals(that.value) :that.value != null) return false;
            return true;
    }




}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V2beta2MetricValueStatusFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V2beta2MetricValueStatusFluentImpl<A extends V2beta2MetricValueStatusFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V2beta2MetricValueStatusFluent<A>{

    private Integer averageUtilization;
    private String averageValue;
    private String value;

    public V2beta2MetricValueStatusFluentImpl(){
    }
    public V2beta2MetricValueStatusFluentImpl(V2beta2MetricValueStatus instance){
            this.withAverageUtilization(instance.getAverageUtilization());

            this.withAverageValue(instance.getAverageValue());

            this.withValue(instance.getValue());

    }

    public Integer getAverageUtilization(){
            return this.averageUtilization;
    }

    public A withAverageUtilization(Integer averageUtilization){
            this.averageUtilization=averageUtilization; return (A) this;
    }

    public Boolean hasAverageUtilization(){
            return this.averageUtilization != null;
    }

    public String getAverageValue(){
            return this.averageValue;
    }

    public A withAverageValue(String averageValue){
            this.averageValue=averageValue; return (A) this;
    }

    public Boolean hasAverageValue(){
            return this.averageValue != null;
    }

    public A withNewAverageValue(String arg1){
            return (A)withAverageValue(new String(arg1));
    }

    public A withNewAverageValue(StringBuilder arg1){
            return (A)withAverageValue(new String(arg1));
    }

    public A withNewAverageValue(StringBuffer arg1){
            return (A)withAverageValue(new String(arg1));
    }

    public String getValue(){
            return this.value;
    }

    public A withValue(String value){
            this.value=value; return (A) this;
    }

    public Boolean hasValue(){
            return this.value != null;
    }

    public A withNewValue(String arg1){
            return (A)withValue(new String(arg1));
    }

    public A withNewValue(StringBuilder arg1){
            return (A)withValue(new String(arg1));
    }

    public A withNewValue(StringBuffer arg1){
            return (A)withValue(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V2beta2MetricValueStatusFluentImpl that = (V2beta2MetricValueStatusFluentImpl) o;
            if (averageUtilization != null ? !averageUtilization.equals(that.averageUtilization) :that.averageUtilization != null) return false;
            if (averageValue != null ? !averageValue.equals(that.averageValue) :that.averageValue != null) return false;
            if (value != null ? !value.equals(that.value) :that.value != null) return false;
            return true;
    }




}
